import json
import logging

import engine


class Stock(object):
    def __init__(self):
        # Initialize the Stock's constants
        self.realtime_url = "https://stock.xueqiu.com/v5/stock/realtime/quotec.json"

        # Initialize the Stock's variables
        self.params = {

        }

        # Initialize the Engine
        self.eg = engine.Engine()

    def get_realtime_quotec(self, code):  # Get the realtime data of quotec
        self.params["symbol"] = code
        txt = self.eg.get_html_text(self.realtime_url, self.params)     # Use the Engine to get the HTML text.
        quotec_json = json.loads(txt)
        # if quotec_json["error_code"] == 0:
        #     logging.info(logging.INFO, "Successfully got the quotec of SH000001")
        # else:
        #     logging.info(logging.ERROR, "Error for getting quotec of SH000001")
        return quotec_json

    def get_realtime_quotec_prize(self, code):
        rt = self.get_realtime_quotec(code)
        if rt["error_code"] == 0:
            return rt["data"][0]["current"]
        else:
            return -1


if __name__ == "__main__":
    st = Stock()
    rt = st.get_realtime_quotec("SH000001")
    print(rt)
    pz = st.get_realtime_quotec_prize("SH000001")
    print(pz)



import requests
import logging


class Engine(object):
    def __init__(self):
        # Initialize the Engine's constants
        self.crawler_head = {'user-agent': 'Mozilla/5.0'}   # The headers of xueqiu website
        self.log_format = "%(asctime)s - %(levelname)s - %(message)s"   # The format of the log message
        self.date_format = "%m%d/%Y %H:%M:%S %p"    # The format of date

        # Initialize the engine's session
        self.session = requests.Session()
        self.session.get("https://xueqiu.com/", headers=self.crawler_head)

        # Set the engine's logging settings
        logging.basicConfig(filename='./log.log', level=logging.DEBUG, format=self.log_format, datefmt=self.date_format)

        logging.log(logging.INFO, "Successfully created session")

    def get_html_text(self, url, param=None):
        try:
            r = self.session.get(url, headers=self.crawler_head, params=param, timeout=30)
            r.raise_for_status()
            r.encoding = r.apparent_encoding
            return r.text
        except requests.exceptions.HTTPError as e:   # HTTPError
            logging.log(logging.ERROR, "HTTPError: for url " + url, e)
            print("HTTPError: for url " + url)
            return ""
        except Exception as e:  # Other Exceptions
            logging.log(logging.ERROR, "Exception: " + str(e))
            print("Exception: " + str(e))
            return ""



import setuptools

README_PATH = './xueqiudanjuan/README.md'

setuptools.setup(
    name='xueqiudanjuan',
    version="0.0.7",
    author='BugMakerH',
    author_email="BugMakerH@gmail.com",
    description="This is a package provided by BugMakerH.",
    long_description=open(README_PATH, encoding='utf-8').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/BugMakerH/xueqiudanjuan.git",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)
